<?

/*
 * Zub's Photo Gallery (ZPG) - A simple PHP photo gallery system
 * Copyright (C) 2004 David Zubillaga
 *
 * This file is part of Zub's Photo Gallery.
 *
 * Zub's Photo Gallery is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 *
 * See README, COPYING or http://www.gnu.org/licenses/gpl.txt for details
 */

require_once("i18n.inc.php");

//////////////////////////////////////////////////////////////////////
// Formatea una fecha. Recibe un timestamp y devuelve un
// string

function format_date($timestamp){
	global $zpg_locale;
	
	$LANG=substr($zpg_locale,0,2);
	
	if ($LANG=="en"){
		return strftime("%A, %B %e, %Y %H:%M",$timestamp);
	}
	else{
		return strftime("%A %e de %B de %Y %H:%M",$timestamp);
	}
}

//////////////////////////////////////////////////////////////////////
// Obtiene la "Fecha de galera" segn el mtime de su
// primera foto. Si el mtime original no est disponible
// por ejemplo, porque se ha subido mediante ftp, lo lee
// de galdate.txt

function get_gal_date($gal){
	global $zpg_gals_dir;
		
	if(file_exists("$zpg_gals_dir/$gal/galdate.txt")){	
		if ($handle_ts=fopen("$zpg_gals_dir/$gal/galdate.txt","r")){
			$timestamp=fgets($handle_ts,32);
			list($y,$m,$d,$h,$min,$s)=explode(":", $timestamp);
		}
		fclose($handle_ts);
		return mktime($h,$min,$s,$m,$d,$y);
	}
	else{
		$photos=get_gal_photo($gal);
		return filemtime("$zpg_gals_dir/$gal/$photos[0]");
	}
}

//////////////////////////////////////////////////////////////////////
// Devuelve una cadena con la cabecera estndar (logo)

function standard_head(){
	global $zpg_gfx_dir,$zpg_logo;

	$size = getimagesize ("$zpg_gfx_dir/$zpg_logo");

	$head=<<<EOT
<div class="logo">
<a href="index.php">
<img src="$zpg_gfx_dir/$zpg_logo" $size[3] border="0" alt="Logo">
</a>
</div>

EOT;

	return $head;
}

//////////////////////////////////////////////////////////////////////
// 

function admin_login_ok(){
	global $passwd;	
	return (($_SESSION['pass']==$passwd['admin']) && ($_SESSION['user']=="admin"));
}


//////////////////////////////////////////////////////////////////////
// Devuelve los datos asociados a una galera

function get_gal_data($gal){
	global $zpg_gal_date, $zpg_gals_dir, $zpg_show_comment;

	if (file_exists("$zpg_gals_dir/$gal/desc.txt")){
		$handle_gal_info=fopen("$zpg_gals_dir/$gal/desc.txt","r");
      
		while(!feof($handle_gal_info)){
			$str=fgets($handle_gal_info,4096);      
			if($str=="\n"){
				$str="<br><br>";
			}
			$gal_desc=$gal_desc . $str;
		}    
	}
	else{
		$gal_desc="";
	}
  
	$photos=get_gal_photo($gal);

	$gal_info["name"]=ucwords(strtr($gal,"_"," "));

	$gal_info["desc"]=$gal_desc;
  
	$gal_info["n_photos"]=count($photos);

	if($zpg_gal_date){    
		$gal_info["ctime"]=filectime("$zpg_gals_dir/$gal");
	}
	else{
		$gal_info["ctime"]=get_gal_date($gal);
	}
  
	return $gal_info;
}

//////////////////////////////////////////////////////////////////////
// Devuelve un array con las galeras existentes (ordenadas segn fecha)

function get_gals_ord(){
	global $zpg_gals_dir, $zpg_gal_date, $zpg_chronologic_order_gal;

	$gals=get_gals();

	$gals_ord=array();
	
	if($gals){    
		foreach($gals as $i){
			$photos=get_gal_photo($i);
			if($zpg_gal_date){
				$time_to_consider=filectime("$zpg_gals_dir/$i");
			}
			else{
				$time_to_consider=get_gal_date($i);
			}
			
			while(array_key_exists($time_to_consider,$gals_ord)){
				$time_to_consider++;
			}
			
			$gals_ord[$time_to_consider]=$i;
		}
		if($zpg_chronologic_order_gal==1){
			ksort($gals_ord);
		}
		else{
			krsort($gals_ord);
		}
	}
	return $gals_ord;
}


//////////////////////////////////////////////////////////////////////
// Devuelve un array con las galerias existentes

function get_gals(){
	global $zpg_gals_dir;
  
	$handle_gals=opendir($zpg_gals_dir);

	while($file=readdir($handle_gals)){
		if(($file!=".") && ($file!="..") && is_dir("$zpg_gals_dir/$file")){
			$gals[]=$file;
		}
	}
	closedir($handle_gals);
  
	return $gals;
}

//////////////////////////////////////////////////////////////////////
// Devuelve una lista con las fotos en $gal

function get_gal_photo($gal){
	global $zpg_gals_dir;
	
	$handle_gal=opendir("$zpg_gals_dir/$gal");

	while($file=readdir($handle_gal)){
		if(is_photo("$zpg_gals_dir/$gal/$file")){    
			$photos[]=$file;    
		}
	}
	closedir($handle_gal);

	return $photos;
}

//////////////////////////////////////////////////////////////////////
// Devuelve una foto aleatoria de $gal

function get_random_photo($gal){
	global $zpg_global_dir;

	$photos=get_gal_photo($gal);

	if(!is_null($photos)){
		$random=array_rand($photos);
		return $photos[$random];
	}
	else{
		return "";
	}
}

//////////////////////////////////////////////////////////////////////
// Devuelve true s y slo s $file es una foto

function is_photo($file){
	$file=basename($file);
  
	if(preg_match("/\.(jpe?g)$|(png)$/i",$file)){
		return TRUE;
	}
	else{
		return FALSE;
	}
}


//////////////////////////////////////////////////////////////////////
// Borra una galera y todo lo que contenga

function rmdirr($dirname)
{
    // Simple delete for a file
    if (is_file($dirname)) {
        return unlink($dirname);
    }

    // Loop through the folder
    $dir = dir($dirname);
    while (false !== $entry = $dir->read()) {
        // Skip pointers
        if ($entry == '.' || $entry == '..') {
            continue;
        }

        // Deep delete directories      
        if (is_dir("$dirname/$entry")) {
            rmdirr("$dirname/$entry");
        } else {
            unlink("$dirname/$entry");
        }
    }

    // Clean up
    $dir->close();
    return rmdir($dirname);
}

//////////////////////////////////////////////////////////////////////
// Devuelve una cadena con el pie estandar (w3c, copyright,
// tiempo de generacin

function standard_foot(){
	global $zpg_show_w3c, $zpg_show_generation_time, $tstart, $zpg_main_title,
	$generator_html,$zpg_copyrighttext, $zpg_copyrightbutton;

	$foot="";

	if ($zpg_show_w3c){
		$foot.= <<< EOT
<p>
 <a href="http://validator.w3.org/check/referer">
 <img border="0" src="gfx/valid-html401-lil.png" alt="Valid HTML 4.01!" height="19" width="55">
 </a>
 <a href="http://jigsaw.w3.org/css-validator/">
 <img border="0" src="gfx/vcss-lil.png" alt="Valid CSS!" height="19" width="55">
 </a>
</p>
EOT;
	}

	$foot.="<p>\n<span class=\"foot\">\n$zpg_main_title - Powered by <a href=\"http://zpg.sourceforge.net\">$generator_html</a>
<br>\n$zpg_copyrighttext\n</span>
<br>\n$zpg_copyrightbutton</p>\n";
	
	if ($zpg_show_generation_time){
		$mtime = microtime();
		$mtime = explode(" ",$mtime);
		$mtime = $mtime[1] + $mtime[0];
		$tend = $mtime;
		$totaltime = ($tend - $tstart);
		
		$foot.=sprintf("<small><small><p>".T("Page generated in")."%2.5f s</p></small></small>",$totaltime);
	}
	
	return $foot;
}

?>
